==> ubuntu_localizations-0.1.3.tar.gz: lib/src/l10n/ubuntu_localizations_ru.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Russian (`ru`).
class UbuntuLocalizationsRu extends UbuntuLocalizations {
  UbuntuLocalizationsRu([String locale = 'ru']) : super(locale);

  @override
  String get countryCode => 'RU';

  @override
  String get languageName => 'Русский';

  @override
  String get backAction => 'Назад';

  @override
  String get continueAction => 'Продолжить';

  @override
  String get strongPassword => 'Надёжный пароль';

  @override
  String get fairPassword => 'Неплохой пароль';

  @override
  String get goodPassword => 'Хороший пароль';

  @override
  String get weakPassword => 'Слабый пароль';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'О приложении';

  @override
  String get addLabel => 'Добавить';

  @override
  String get allLabel => 'Все';

  @override
  String get applyLabel => 'Применить';

  @override
  String get ascendingLabel => 'По возрастанию';

  @override
  String get backLabel => 'Назад';

  @override
  String get boldLabel => 'Жирный';

  @override
  String get bottomLabel => 'Снизу';

  @override
  String get cancelLabel => 'Отмена';

  @override
  String get centerLabel => 'Центр';

  @override
  String get clearLabel => 'Очистить';

  @override
  String get closeLabel => 'Закрыть';

  @override
  String get colorLabel => 'Цвет';

  @override
  String get connectLabel => 'Соединение';

  @override
  String get continueLabel => 'Продолжить';

  @override
  String get copyLabel => 'Копировать';

  @override
  String get createLabel => 'Создать';

  @override
  String get cutLabel => 'Вырезать';

  @override
  String get decreaseLabel => 'Уменьшить';

  @override
  String get deleteLabel => 'Удалить';

  @override
  String get descendingLabel => 'По убыванию';

  @override
  String get discardLabel => 'Отказаться';

  @override
  String get disconnectLabel => 'Разъединить';

  @override
  String get doneLabel => 'Готово';

  @override
  String get downloadLabel => 'Загрузить';

  @override
  String get editLabel => 'Правка';

  @override
  String get enterLabel => 'Ввод';

  @override
  String get errorLabel => 'Ошибка';

  @override
  String get executeLabel => 'Выполнить';

  @override
  String get exitLabel => 'Выход';

  @override
  String get fileLabel => 'Файл';

  @override
  String get fillLabel => 'Заполнить';

  @override
  String get findLabel => 'Найти';

  @override
  String get firstLabel => 'Первый';

  @override
  String get fontLabel => 'Шрифт';

  @override
  String get forwardLabel => 'Вперед';

  @override
  String get fullscreenLabel => 'Во весь экран';

  @override
  String get goBackLabel => 'Назад';

  @override
  String get helpLabel => 'Справка';

  @override
  String get homeLabel => 'Домой';

  @override
  String get importLabel => 'Импорт';

  @override
  String get increaseLabel => 'Увеличить';

  @override
  String get indexLabel => 'Индекс';

  @override
  String get informationLabel => 'Сведения';

  @override
  String get insertLabel => 'Вставлять';

  @override
  String get italicLabel => 'Курсив';

  @override
  String get landscapeLabel => 'Ландшафт';

  @override
  String get lastLabel => 'Последний';

  @override
  String get leaveLabel => 'Покинуть';

  @override
  String get leftLabel => 'Слева';

  @override
  String get mediaLabel => 'Медиа';

  @override
  String get networkLabel => 'Сеть';

  @override
  String get newLabel => 'New';

  @override
  String get nextLabel => 'Следующая';

  @override
  String get noLabel => 'Нет';

  @override
  String get noneLabel => 'Ничего';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Открыть';

  @override
  String get pasteLabel => 'Вставить';

  @override
  String get pauseLabel => 'Пауза';

  @override
  String get playLabel => 'Воспроизвести';

  @override
  String get portraitLabel => 'Портрет';

  @override
  String get preferencesLabel => 'Параметры';

  @override
  String get previousLabel => 'Предыдущая';

  @override
  String get printLabel => 'Печать';

  @override
  String get printPreviewLabel => 'Предварительный просмотр печати';

  @override
  String get propertiesLabel => 'Характеристики';

  @override
  String get questionLabel => 'Вопрос';

  @override
  String get quitLabel => 'Завершить';

  @override
  String get recordLabel => 'Запись';

  @override
  String get redoLabel => 'Вернуть';

  @override
  String get refreshLabel => 'Обновить';

  @override
  String get removeLabel => 'Удалить';

  @override
  String get renameLabel => 'Переименовать';

  @override
  String get resetLabel => 'Сбросить';

  @override
  String get restoreLabel => 'Восстановить';

  @override
  String get retryLabel => 'Повторить';

  @override
  String get revertLabel => 'Вернуть';

  @override
  String get rewindLabel => 'Перемотка';

  @override
  String get rightLabel => 'Справа';

  @override
  String get saveAsLabel => 'Сохранить как';

  @override
  String get saveLabel => 'Сохранить';

  @override
  String get searchLabel => 'Поиск';

  @override
  String get selectAllLabel => 'Выделить все';

  @override
  String get selectLabel => 'Выделить';

  @override
  String get sendLabel => 'Отправить';

  @override
  String get skipLabel => 'Пропустить';

  @override
  String get sortLabel => 'Сортировать';

  @override
  String get stopLabel => 'Остановить';

  @override
  String get strikeThroughLabel => 'Зачеркнуть';

  @override
  String get submitLabel => 'Submit';

  @override
  String get topLabel => 'Сверху';

  @override
  String get undoLabel => 'Отменить';

  @override
  String get updateLabel => 'Обновить';

  @override
  String get upLabel => 'Вверх';

  @override
  String get viewLabel => 'Вид';

  @override
  String get warningLabel => 'Предупреждение';

  @override
  String get windowLabel => 'Окно';

  @override
  String get yesLabel => 'Да';

  @override
  String get zoomInLabel => 'Увеличить масштаб';

  @override
  String get zoomOutLabel => 'Уменьшить масштаб';
}

==> ubuntu_localizations-0.1.6.tar.gz: lib/src/l10n/ubuntu_localizations_ru.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Russian (`ru`).
class UbuntuLocalizationsRu extends UbuntuLocalizations {
  UbuntuLocalizationsRu([String locale = 'ru']) : super(locale);

  @override
  String get countryCode => 'RU';

  @override
  String get languageName => 'Русский';

  @override
  String get backAction => 'Назад';

  @override
  String get continueAction => 'Продолжить';

  @override
  String get strongPassword => 'Надёжный пароль';

  @override
  String get fairPassword => 'Неплохой пароль';

  @override
  String get goodPassword => 'Хороший пароль';

  @override
  String get weakPassword => 'Слабый пароль';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'О приложении';

  @override
  String get addLabel => 'Добавить';

  @override
  String get allLabel => 'Все';

  @override
  String get applyLabel => 'Применить';

  @override
  String get ascendingLabel => 'По возрастанию';

  @override
  String get backLabel => 'Назад';

  @override
  String get boldLabel => 'Жирный';

  @override
  String get bottomLabel => 'Снизу';

  @override
  String get cancelLabel => 'Отмена';

  @override
  String get centerLabel => 'Центр';

  @override
  String get clearLabel => 'Очистить';

  @override
  String get closeLabel => 'Закрыть';

  @override
  String get colorLabel => 'Цвет';

  @override
  String get connectLabel => 'Соединение';

  @override
  String get continueLabel => 'Продолжить';

  @override
  String get copyLabel => 'Копировать';

  @override
  String get createLabel => 'Создать';

  @override
  String get cutLabel => 'Вырезать';

  @override
  String get decreaseLabel => 'Уменьшить';

  @override
  String get deleteLabel => 'Удалить';

  @override
  String get descendingLabel => 'По убыванию';

  @override
  String get discardLabel => 'Отказаться';

  @override
  String get disconnectLabel => 'Разъединить';

  @override
  String get doneLabel => 'Готово';

  @override
  String get downloadLabel => 'Загрузить';

  @override
  String get editLabel => 'Правка';

  @override
  String get enterLabel => 'Ввод';

  @override
  String get errorLabel => 'Ошибка';

  @override
  String get executeLabel => 'Выполнить';

  @override
  String get exitLabel => 'Выход';

  @override
  String get fileLabel => 'Файл';

  @override
  String get fillLabel => 'Заполнить';

  @override
  String get findLabel => 'Найти';

  @override
  String get firstLabel => 'Первый';

  @override
  String get fontLabel => 'Шрифт';

  @override
  String get forwardLabel => 'Вперед';

  @override
  String get fullscreenLabel => 'Во весь экран';

  @override
  String get goBackLabel => 'Назад';

  @override
  String get helpLabel => 'Справка';

  @override
  String get homeLabel => 'Домой';

  @override
  String get importLabel => 'Импорт';

  @override
  String get increaseLabel => 'Увеличить';

  @override
  String get indexLabel => 'Индекс';

  @override
  String get informationLabel => 'Сведения';

  @override
  String get insertLabel => 'Вставлять';

  @override
  String get italicLabel => 'Курсив';

  @override
  String get landscapeLabel => 'Ландшафт';

  @override
  String get lastLabel => 'Последний';

  @override
  String get leaveLabel => 'Покинуть';

  @override
  String get leftLabel => 'Слева';

  @override
  String get mediaLabel => 'Медиа';

  @override
  String get networkLabel => 'Сеть';

  @override
  String get newLabel => 'Новый';

  @override
  String get nextLabel => 'Следующая';

  @override
  String get noLabel => 'Нет';

  @override
  String get noneLabel => 'Ничего';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Открыть';

  @override
  String get pasteLabel => 'Вставить';

  @override
  String get pauseLabel => 'Пауза';

  @override
  String get playLabel => 'Воспроизвести';

  @override
  String get portraitLabel => 'Портрет';

  @override
  String get preferencesLabel => 'Параметры';

  @override
  String get previousLabel => 'Предыдущая';

  @override
  String get printLabel => 'Печать';

  @override
  String get printPreviewLabel => 'Предварительный просмотр печати';

  @override
  String get propertiesLabel => 'Характеристики';

  @override
  String get questionLabel => 'Вопрос';

  @override
  String get quitLabel => 'Завершить';

  @override
  String get recordLabel => 'Запись';

  @override
  String get redoLabel => 'Вернуть';

  @override
  String get refreshLabel => 'Обновить';

  @override
  String get removeLabel => 'Удалить';

  @override
  String get renameLabel => 'Переименовать';

  @override
  String get resetLabel => 'Сбросить';

  @override
  String get restoreLabel => 'Восстановить';

  @override
  String get retryLabel => 'Повторить';

  @override
  String get revertLabel => 'Вернуть';

  @override
  String get rewindLabel => 'Перемотка';

  @override
  String get rightLabel => 'Справа';

  @override
  String get saveAsLabel => 'Сохранить как';

  @override
  String get saveLabel => 'Сохранить';

  @override
  String get searchLabel => 'Поиск';

  @override
  String get selectAllLabel => 'Выделить все';

  @override
  String get selectLabel => 'Выделить';

  @override
  String get sendLabel => 'Отправить';

  @override
  String get skipLabel => 'Пропустить';

  @override
  String get sortLabel => 'Сортировать';

  @override
  String get stopLabel => 'Остановить';

  @override
  String get strikeThroughLabel => 'Зачёркнутый';

  @override
  String get submitLabel => 'Отправить';

  @override
  String get topLabel => 'Сверху';

  @override
  String get undoLabel => 'Отменить';

  @override
  String get updateLabel => 'Обновить';

  @override
  String get upLabel => 'Вверх';

  @override
  String get viewLabel => 'Вид';

  @override
  String get warningLabel => 'Предупреждение';

  @override
  String get windowLabel => 'Окно';

  @override
  String get yesLabel => 'Да';

  @override
  String get zoomInLabel => 'Увеличить масштаб';

  @override
  String get zoomOutLabel => 'Уменьшить масштаб';
}
